```
Usage: vcd gateway enable-distributed-routing [OPTIONS] <gateway name>

Options:
  --enable / --disable  Enable distributed routing for networks connected to
                        this gateway.
  -h, --help            Show this message and exit.

```
